@@ -1,4 +1,3 @@
-from tkinter import N
 from unittest import main, TestCase
 
 from baraldi_fib_py.fib_calcs.fib_number import recurring_fib_num
@@ -9,7 +8,9 @@ class RecurringFibNumberTest(TestCase):
         self.assertEqual(0, recurring_fib_num(num=0))
 
     def test_negative(self):
-        self.assertEqual(None, recurring_fib_num(num=-1))
+        with self.assertRaises(ValueError) as raised_error:
+            recurring_fib_num(num=-1)
+        self.assertEqual("Fibonacci has to be equal or above zero.", str(raised_error.exception))
 
     def test_one(self):
         self.assertEqual(1, recurring_fib_num(num=1))
